[−][src]Struct arc_swap::gen_lock::Global
The default, global lock.
The lock is stored out-of-band, globally. This means that one ArcSwap with this lock storage
is only one machine word large, but a lock on one instance blocks the other, independent ones.
It has several shards so threads are less likely to collide (HW-contend) on them.